Index<Key, Record> class abstract

Implementers

Constructors

Index(GetKey<Key, Record> getKey)

Properties

getKey GetKey<Key, Record>
final
hashCode int
The hash code for this object.
no setterinherited
keys Iterable<Key>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<Record>
no setter

Methods

add(Record record) → void
addAll(Iterable<Record> records) → void
getOne(Key key) → Record?
has(Key key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Record record) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited