getAll method
OrderedSet<Record>
getAll(
- Key key
Retrieve all values associated with the key, in order.
Implementation
OrderedSet<Record> getAll(Key key) => _data[key] ?? OrderedSet<Record>();
Retrieve all values associated with the key, in order.
OrderedSet<Record> getAll(Key key) => _data[key] ?? OrderedSet<Record>();