values property
Returns the total number of records in this index (may be more than
the size of keys because each key can store multiple records)
Implementation
@override
Iterable<Record> get values sync* {
for (var list in _data.values) {
for (var item in list) {
yield item;
}
}
}